@@ -50,9 +50,23 @@ def from_array(value, name=None):
     :return: ONNX tensor
     """
     if isinstance(value, numpy.ndarray):
-        pb = onnx_from_array(value, name=name)
+        try:
+            pb = onnx_from_array(value, name=name)
+        except NotImplementedError as e:  # pragma: no cover
+            if value.dtype == numpy.dtype('O'):
+                pb = TensorProto()
+                pb.data_type = TensorProto.STRING  # pylint: disable=E1101
+                if name is not None:
+                    pb.name = name
+                pb.dims.extend(value.shape)  # pylint: disable=E1101
+                pb.string_data.extend(  # pylint: disable=E1101
+                    list(map(lambda o: str(o).encode('utf-8'), value.ravel())))
+            else:
+                raise NotImplementedError(
+                    "Unable to convert type %r (dtype=%r) into an ONNX tensor "
+                    "due to %r." % (type(value), value.dtype, e)) from e
         return pb
-    if isinstance(value, TensorProto):
+    if isinstance(value, TensorProto):  # pragma: no cover
         return value
     raise NotImplementedError(
         "Unable to convert type %r into an ONNX tensor." % type(value))
@@ -158,7 +172,7 @@ def guess_numpy_type_from_string(name):
         return numpy.bool_
     if name == 'str':
         return numpy.str_
-    raise ValueError(
+    raise ValueError(  # pragma: no cover
         "Unable to guess numpy dtype from %r." % name)
 
 
@@ -182,7 +196,7 @@ def guess_numpy_type_from_dtype(dt):
         return numpy.int8
     if dt == numpy.dtype('uint8'):
         return numpy.uint8
-    raise ValueError(
+    raise ValueError(  # pragma: no cover
         "Unable to guess numpy dtype from %r." % dt)
 
 
